django-pki - Web-based PKI — django-pki v0.20.0 documentation

### Navigation

- index
- next |
- django-pki v0.20.0 documentation »

# django-pki - Web-based PKI

django-pki is a PKI based on Django ;-)

## Introduction

This project aims to simplify the installation and management of your personal CA infrastructure. Features include:

- Create CA chains based on self-signed Root CA’s
- CA’s can contain other CA’s or non-CA certificates
- Automatic CRL generation/update when CA or related certificate is modified
- Creation and export of PEM, PKCS12 and DER encoded versions
- Revoke and renew of certificates

## Online Resources

Sourcecode repository:
  https://github.com/dkerwin/django-pki/
Documentation:
  http://dkerwin.github.com/django-pki/
Issue tracker:
  https://github.com/dkerwin/django-pki/issues
Discussion:
  http://groups.google.com/group/django-pki

## Getting started

- 1. Installation
  - 1.1. Prequisites
  - 1.2. pip / easy_install
  - 1.3. Sourcecode from GitHub
- 2. Configuration
  - 2.1. Create and configure a new Django project
  - 2.2. Edit project’s settings.py
  - 2.3. Configure django-pki settings (in projects settings.py)
  - 2.4. Configure projects urls.py
  - 2.5. Initialize database
  - 2.6. PKI store layout (PKI_DIR)
- 3. Upgrade instructions
  - 3.1. Database migration
  - 3.2. Update project’s urls.py

## Tutorial

Coming soon...

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- django-pki v0.20.0 documentation »